.. currentmodule:: pvlib

.. _dniestmodels:

DNI estimation models
---------------------

.. autosummary::
   :toctree: ../generated/

   irradiance.disc
   irradiance.dirint
   irradiance.dirindex
   irradiance.erbs
   irradiance.campbell_norman
   irradiance.gti_dirint
